summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sys/arch/alpha/alpha/autoconf.c6
-rw-r--r--sys/arch/alpha/alpha/machdep.c4
-rw-r--r--sys/arch/alpha/include/autoconf.h3
-rw-r--r--sys/arch/amiga/amiga/autoconf.c4
-rw-r--r--sys/arch/amiga/amiga/machdep.c6
-rw-r--r--sys/arch/amiga/include/cpu.h3
-rw-r--r--sys/arch/hp300/hp300/autoconf.c6
-rw-r--r--sys/arch/hp300/hp300/machdep.c3
-rw-r--r--sys/arch/hp300/include/autoconf.h3
-rw-r--r--sys/arch/hppa/hppa/autoconf.c6
-rw-r--r--sys/arch/hppa/hppa/machdep.c3
-rw-r--r--sys/arch/hppa/include/autoconf.h3
-rw-r--r--sys/arch/i386/i386/autoconf.c8
-rw-r--r--sys/arch/i386/i386/machdep.c3
-rw-r--r--sys/arch/i386/include/cpu.h5
-rw-r--r--sys/arch/mac68k/include/autoconf.h3
-rw-r--r--sys/arch/mac68k/mac68k/autoconf.c10
-rw-r--r--sys/arch/mac68k/mac68k/machdep.c3
-rw-r--r--sys/arch/mvme68k/mvme68k/autoconf.c7
-rw-r--r--sys/arch/mvme68k/mvme68k/machdep.c3
-rw-r--r--sys/arch/mvme88k/mvme88k/autoconf.c5
-rw-r--r--sys/arch/mvme88k/mvme88k/machdep.c4
-rw-r--r--sys/arch/pmax/include/autoconf.h1
-rw-r--r--sys/arch/pmax/pmax/autoconf.c7
-rw-r--r--sys/arch/pmax/pmax/machdep.c7
-rw-r--r--sys/arch/powerpc/powerpc/autoconf.c9
-rw-r--r--sys/arch/powerpc/powerpc/machdep.c6
-rw-r--r--sys/arch/sparc/include/autoconf.h3
-rw-r--r--sys/arch/sparc/sparc/autoconf.c10
-rw-r--r--sys/arch/sparc/sparc/machdep.c7
-rw-r--r--sys/arch/sun3/include/cpu.h5
-rw-r--r--sys/arch/sun3/include/machdep.h3
-rw-r--r--sys/arch/sun3/sun3/autoconf.c8
-rw-r--r--sys/arch/sun3/sun3/machdep.c3
-rw-r--r--sys/arch/vax/include/cpu.h4
-rw-r--r--sys/arch/vax/vax/autoconf.c18
-rw-r--r--sys/arch/vax/vax/machdep.c3
-rw-r--r--sys/kern/init_main.c3
-rw-r--r--sys/sys/systm.h3
39 files changed, 75 insertions, 126 deletions
diff --git a/sys/arch/alpha/alpha/autoconf.c b/sys/arch/alpha/alpha/autoconf.c
index 321bcf3feb1..d907108360c 100644
--- a/sys/arch/alpha/alpha/autoconf.c
+++ b/sys/arch/alpha/alpha/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.10 2000/11/08 16:00:54 art Exp $ */
+/* $OpenBSD: autoconf.c,v 1.11 2001/05/05 22:33:22 art Exp $ */
/* $NetBSD: autoconf.c,v 1.16 1996/11/13 21:13:04 cgd Exp $ */
/*
@@ -81,11 +81,11 @@ static char *findblkname __P((int));
static int getstr __P((char *cp, int size));
/*
- * configure:
+ * cpu_configure:
* called at boot time, configure all devices on system
*/
void
-configure()
+cpu_configure()
{
extern int cold;
diff --git a/sys/arch/alpha/alpha/machdep.c b/sys/arch/alpha/alpha/machdep.c
index 81b0ab7c36f..c654f1e355b 100644
--- a/sys/arch/alpha/alpha/machdep.c
+++ b/sys/arch/alpha/alpha/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.44 2001/05/05 20:56:30 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.45 2001/05/05 22:33:23 art Exp $ */
/* $NetBSD: machdep.c,v 1.206 2000/05/23 05:12:54 thorpej Exp $ */
/*-
@@ -1032,8 +1032,6 @@ cpu_startup()
* CPUs.
*/
hwrpb_primary_init();
-
- configure();
}
/*
diff --git a/sys/arch/alpha/include/autoconf.h b/sys/arch/alpha/include/autoconf.h
index e23cc6c1097..24c14880716 100644
--- a/sys/arch/alpha/include/autoconf.h
+++ b/sys/arch/alpha/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.10 2000/11/08 21:44:35 art Exp $ */
+/* $OpenBSD: autoconf.h,v 1.11 2001/05/05 22:33:26 art Exp $ */
/* $NetBSD: autoconf.h,v 1.19 2000/06/08 03:10:06 thorpej Exp $ */
/*
@@ -118,6 +118,5 @@ const char *alpha_variation_name(u_int64_t,
const struct alpha_variation_table *);
const char *alpha_unknown_sysname(void);
-void configure __P((void));
void device_register __P((struct device *, void *));
#endif /* _KERNEL */
diff --git a/sys/arch/amiga/amiga/autoconf.c b/sys/arch/amiga/amiga/autoconf.c
index 64664d3b99c..2a39b81fb8f 100644
--- a/sys/arch/amiga/amiga/autoconf.c
+++ b/sys/arch/amiga/amiga/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.13 2000/09/02 13:45:38 espie Exp $ */
+/* $OpenBSD: autoconf.c,v 1.14 2001/05/05 22:33:28 art Exp $ */
/* $NetBSD: autoconf.c,v 1.59 1998/01/15 21:55:51 is Exp $ */
/*
@@ -53,7 +53,7 @@ int cold; /* 1 if still booting */
* called at boot time, configure all devices on system
*/
void
-configure()
+cpu_configure()
{
int s;
diff --git a/sys/arch/amiga/amiga/machdep.c b/sys/arch/amiga/amiga/machdep.c
index d028c7820e3..13d498d0fec 100644
--- a/sys/arch/amiga/amiga/machdep.c
+++ b/sys/arch/amiga/amiga/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.42 2001/05/05 20:56:32 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.43 2001/05/05 22:33:28 art Exp $ */
/* $NetBSD: machdep.c,v 1.95 1997/08/27 18:31:17 is Exp $ */
/*
@@ -603,10 +603,6 @@ again:
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
-#ifdef DEBUG_KERNEL_START
- printf("survived configure...\n");
-#endif
}
/*
diff --git a/sys/arch/amiga/include/cpu.h b/sys/arch/amiga/include/cpu.h
index c44d8bcd522..90c451d30fa 100644
--- a/sys/arch/amiga/include/cpu.h
+++ b/sys/arch/amiga/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.12 1998/03/01 00:37:22 niklas Exp $ */
+/* $OpenBSD: cpu.h,v 1.13 2001/05/05 22:33:31 art Exp $ */
/* $NetBSD: cpu.h,v 1.36 1996/09/11 00:11:42 thorpej Exp $ */
/*
@@ -153,7 +153,6 @@ void *alloc_z2mem __P((long));
/*
* Prototypes from autoconf.c
*/
-void configure __P((void));
int is_a1200 __P((void));
int is_a3000 __P((void));
int is_a4000 __P((void));
diff --git a/sys/arch/hp300/hp300/machdep.c b/sys/arch/hp300/hp300/machdep.c
index 9e7c9511e17..aa56dd72814 100644
--- a/sys/arch/hp300/hp300/machdep.c
+++ b/sys/arch/hp300/hp300/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.42 2001/05/05 20:56:34 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.43 2001/05/05 22:33:34 art Exp $ */
/* $NetBSD: machdep.c,v 1.121 1999/03/26 23:41:29 mycroft Exp $ */
/*
@@ -488,7 +488,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/hp300/include/autoconf.h b/sys/arch/hp300/include/autoconf.h
index 4dfc2583426..1b2daccb169 100644
--- a/sys/arch/hp300/include/autoconf.h
+++ b/sys/arch/hp300/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.4 1997/04/16 11:56:33 downsj Exp $ */
+/* $OpenBSD: autoconf.h,v 1.5 2001/05/05 22:33:37 art Exp $ */
/* $NetBSD: autoconf.h,v 1.4 1997/04/01 03:03:56 scottr Exp $ */
/*-
@@ -44,7 +44,6 @@ extern caddr_t conaddr; /* KVA of console device */
extern int convasize; /* size of mapping at conaddr */
extern int conforced; /* console has been forced */
-void configure __P((void));
void hp300_cninit __P((void));
void console_scan __P((int (*)(int, caddr_t, void *), void *));
caddr_t iomap __P((caddr_t, int));
diff --git a/sys/arch/hppa/hppa/autoconf.c b/sys/arch/hppa/hppa/autoconf.c
index 7b095626d77..4fa24058b42 100644
--- a/sys/arch/hppa/hppa/autoconf.c
+++ b/sys/arch/hppa/hppa/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.13 2001/04/01 06:25:33 mickey Exp $ */
+/* $OpenBSD: autoconf.c,v 1.14 2001/05/05 22:33:39 art Exp $ */
/*
* Copyright (c) 1998-2001 Michael Shalayeff
@@ -80,11 +80,11 @@ extern int hz;
#endif
/*
- * configure:
+ * cpu_configure:
* called at boot time, configure all devices on system
*/
void
-configure()
+cpu_configure()
{
extern int cold;
diff --git a/sys/arch/hppa/hppa/machdep.c b/sys/arch/hppa/hppa/machdep.c
index a6777000f3e..90ed27ba5b8 100644
--- a/sys/arch/hppa/hppa/machdep.c
+++ b/sys/arch/hppa/hppa/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.32 2001/05/05 20:56:36 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.33 2001/05/05 22:33:40 art Exp $ */
/*
* Copyright (c) 1999-2000 Michael Shalayeff
@@ -704,7 +704,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/hppa/include/autoconf.h b/sys/arch/hppa/include/autoconf.h
index 522541e82b7..61a1989e168 100644
--- a/sys/arch/hppa/include/autoconf.h
+++ b/sys/arch/hppa/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.9 1999/08/16 02:48:40 mickey Exp $ */
+/* $OpenBSD: autoconf.h,v 1.10 2001/05/05 22:33:42 art Exp $ */
/*
* Copyright (c) 1998 Michael Shalayeff
@@ -66,5 +66,4 @@ void *cpu_intr_establish __P((int pri, int, int (*handler) __P((void *)),
void *arg, struct device *name));
int clock_intr __P((void *));
-void configure __P((void));
void dumpconf __P((void));
diff --git a/sys/arch/i386/i386/machdep.c b/sys/arch/i386/i386/machdep.c
index 2fd66ad6f09..30ff3a17f89 100644
--- a/sys/arch/i386/i386/machdep.c
+++ b/sys/arch/i386/i386/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.157 2001/05/05 20:56:38 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.158 2001/05/05 22:33:45 art Exp $ */
/* $NetBSD: machdep.c,v 1.214 1996/11/10 03:16:17 thorpej Exp $ */
/*-
@@ -469,7 +469,6 @@ cpu_startup()
#endif
}
ioport_malloc_safe = 1;
- configure();
}
/*
diff --git a/sys/arch/i386/include/cpu.h b/sys/arch/i386/include/cpu.h
index 17d31917151..22d2c229e2a 100644
--- a/sys/arch/i386/include/cpu.h
+++ b/sys/arch/i386/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.35 2001/04/30 13:23:11 art Exp $ */
+/* $OpenBSD: cpu.h,v 1.36 2001/05/05 22:33:48 art Exp $ */
/* $NetBSD: cpu.h,v 1.35 1996/05/05 19:29:26 christos Exp $ */
/*-
@@ -174,9 +174,6 @@ extern int cpu_f00f_bug;
void fix_f00f __P((void));
#endif
-/* autoconf.c */
-void configure __P((void));
-
/* dkcsum.c */
void dkcsumattach __P((void));
diff --git a/sys/arch/mac68k/include/autoconf.h b/sys/arch/mac68k/include/autoconf.h
index ba1fd0f7bff..c95b3b5a8b3 100644
--- a/sys/arch/mac68k/include/autoconf.h
+++ b/sys/arch/mac68k/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.6 1997/11/30 06:10:29 gene Exp $ */
+/* $OpenBSD: autoconf.h,v 1.7 2001/05/05 22:33:50 art Exp $ */
/* $NetBSD: autoconf.h,v 1.5 1996/12/17 06:47:40 scottr Exp $ */
/*
@@ -44,7 +44,6 @@
#ifdef _KERNEL
/* autoconf.c */
void setconf __P((void));
-void configure __P((void));
/* machdep.c */
void mac68k_set_io_offsets __P((vm_offset_t));
diff --git a/sys/arch/mac68k/mac68k/machdep.c b/sys/arch/mac68k/mac68k/machdep.c
index 505f56d1cef..ca0a868d614 100644
--- a/sys/arch/mac68k/mac68k/machdep.c
+++ b/sys/arch/mac68k/mac68k/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.68 2001/05/05 20:56:41 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.69 2001/05/05 22:33:54 art Exp $ */
/* $NetBSD: machdep.c,v 1.134 1997/02/14 06:15:30 scottr Exp $ */
/*
@@ -503,7 +503,6 @@ again:
#endif
}
iomem_malloc_safe = 1;
- configure();
}
void doboot __P((void))
diff --git a/sys/arch/mvme68k/mvme68k/machdep.c b/sys/arch/mvme68k/mvme68k/machdep.c
index 0ee732ea93c..af79cf637f9 100644
--- a/sys/arch/mvme68k/mvme68k/machdep.c
+++ b/sys/arch/mvme68k/mvme68k/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.37 2001/05/05 20:56:45 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.38 2001/05/05 22:33:58 art Exp $ */
/*
* Copyright (c) 1995 Theo de Raadt
@@ -449,7 +449,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/mvme88k/mvme88k/autoconf.c b/sys/arch/mvme88k/mvme88k/autoconf.c
index 0adec0132c1..4a187a995d1 100644
--- a/sys/arch/mvme88k/mvme88k/autoconf.c
+++ b/sys/arch/mvme88k/mvme88k/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.11 2001/04/29 19:00:02 miod Exp $ */
+/* $OpenBSD: autoconf.c,v 1.12 2001/05/05 22:34:01 art Exp $ */
/*
* Copyright (c) 1998 Steve Murphree, Jr.
* Copyright (c) 1996 Nivas Madhur
@@ -59,7 +59,6 @@
struct device *parsedisk __P((char *, int, int, dev_t *));
void setroot __P((void));
void swapconf __P((void));
-void configure __P((void));
char buginchr __P((void));
int getsb __P((char *, int));
void dumpconf __P((void));
@@ -72,7 +71,7 @@ int cold; /* 1 if still booting */
* called at boot time, configure all devices on the system.
*/
void
-configure()
+cpu_configure()
{
bootdv = NULL; /* set by device drivers (if found) */
diff --git a/sys/arch/mvme88k/mvme88k/machdep.c b/sys/arch/mvme88k/mvme88k/machdep.c
index ebb42aab866..c701e0cfcda 100644
--- a/sys/arch/mvme88k/mvme88k/machdep.c
+++ b/sys/arch/mvme88k/mvme88k/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.33 2001/05/05 20:56:47 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.34 2001/05/05 22:34:02 art Exp $ */
/*
* Copyright (c) 1998, 1999, 2000, 2001 Steve Murphree, Jr.
* Copyright (c) 1996 Nivas Madhur
@@ -129,7 +129,6 @@ void m88110_Xfp_precise __P((void));
void setupiackvectors __P((void));
void regdump __P((struct trapframe *f));
void dumpsys __P((void));
-void configure __P((void));
void consinit __P((void));
void kdb_init __P((void));
@@ -822,7 +821,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/pmax/include/autoconf.h b/sys/arch/pmax/include/autoconf.h
index ac1d235bba5..0007e54cb7a 100644
--- a/sys/arch/pmax/include/autoconf.h
+++ b/sys/arch/pmax/include/autoconf.h
@@ -74,5 +74,4 @@ void set_clockintr __P((void (*)(struct clockframe *)));
#endif
void set_iointr __P((void (*)(void *, int)));
int badaddr __P((void *, u_int));
-void configure __P((void));
void makebootdev __P((char *cp));
diff --git a/sys/arch/pmax/pmax/machdep.c b/sys/arch/pmax/pmax/machdep.c
index aba014f8295..d102b95a81f 100644
--- a/sys/arch/pmax/pmax/machdep.c
+++ b/sys/arch/pmax/pmax/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.27 2001/05/05 20:56:49 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.28 2001/05/05 22:34:09 art Exp $ */
/* $NetBSD: machdep.c,v 1.67 1996/10/23 20:04:40 mhitch Exp $ */
/*
@@ -885,11 +885,6 @@ cpu_startup()
* Set up CPU-specific registers, cache, etc.
*/
initcpu();
-
- /*
- * Configure the system.
- */
- configure();
}
/*
diff --git a/sys/arch/powerpc/powerpc/machdep.c b/sys/arch/powerpc/powerpc/machdep.c
index d7441484a2f..a23bca9f230 100644
--- a/sys/arch/powerpc/powerpc/machdep.c
+++ b/sys/arch/powerpc/powerpc/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.58 2001/05/05 20:56:51 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.59 2001/05/05 22:34:14 art Exp $ */
/* $NetBSD: machdep.c,v 1.4 1996/10/16 19:33:11 ws Exp $ */
/*
@@ -582,11 +582,7 @@ cpu_startup()
*/
bufinit();
- /*
- * Configure devices.
- */
devio_malloc_safe = 1;
- configure();
}
diff --git a/sys/arch/sparc/include/autoconf.h b/sys/arch/sparc/include/autoconf.h
index 55b895a1f7a..88688854650 100644
--- a/sys/arch/sparc/include/autoconf.h
+++ b/sys/arch/sparc/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.7 1999/07/23 19:11:27 jason Exp $ */
+/* $OpenBSD: autoconf.h,v 1.8 2001/05/05 22:34:17 art Exp $ */
/* $NetBSD: autoconf.h,v 1.20 1997/05/24 20:03:03 pk Exp $ */
/*
@@ -209,7 +209,6 @@ struct device *parsedisk __P((char *, int, int, dev_t *));
void mountroot_hook_establish __P((void (*) __P((struct device *)),
struct device *));
-void configure __P((void));
void bootstrap __P((void));
int firstchild __P((int));
int nextsibling __P((int));
diff --git a/sys/arch/sparc/sparc/machdep.c b/sys/arch/sparc/sparc/machdep.c
index 5328206389a..3fe606b197c 100644
--- a/sys/arch/sparc/sparc/machdep.c
+++ b/sys/arch/sparc/sparc/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.55 2001/05/05 21:26:41 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.56 2001/05/05 22:34:19 art Exp $ */
/* $NetBSD: machdep.c,v 1.85 1997/09/12 08:55:02 pk Exp $ */
/*
@@ -373,11 +373,6 @@ cpu_startup()
* Set up buffers, so they can be used to read disk labels.
*/
bufinit();
-
- /*
- * Configure the system. The cpu code will turn on the cache.
- */
- configure();
}
/*
diff --git a/sys/arch/sun3/include/cpu.h b/sys/arch/sun3/include/cpu.h
index 8194c5b979e..664f4e6f15c 100644
--- a/sys/arch/sun3/include/cpu.h
+++ b/sys/arch/sun3/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.11 2000/03/02 23:01:45 todd Exp $ */
+/* $OpenBSD: cpu.h,v 1.12 2001/05/05 22:34:21 art Exp $ */
/* $NetBSD: cpu.h,v 1.20 1995/12/21 05:02:10 mycroft Exp $ */
/*
@@ -158,9 +158,6 @@ union sun3sir {
extern unsigned char cpu_machine_id;
-/* autoconf.c */
-void configure __P((void));
-
/* dma.c */
long dvma_kvtopa __P((long, int));
diff --git a/sys/arch/sun3/include/machdep.h b/sys/arch/sun3/include/machdep.h
index a643dd8e7ec..3a650050df8 100644
--- a/sys/arch/sun3/include/machdep.h
+++ b/sys/arch/sun3/include/machdep.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.h,v 1.11 2001/01/03 01:48:07 miod Exp $ */
+/* $OpenBSD: machdep.h,v 1.12 2001/05/05 22:34:22 art Exp $ */
/*
* Copyright (c) 1994 Gordon W. Ross
@@ -87,7 +87,6 @@ int cachectl __P((int req, caddr_t addr, int len));
void child_return __P((void *));
-void configure __P((void));
void cninit __P((void));
void dumpconf __P((void));
diff --git a/sys/arch/sun3/sun3/machdep.c b/sys/arch/sun3/sun3/machdep.c
index df8b8cf0433..d0b3c2955f8 100644
--- a/sys/arch/sun3/sun3/machdep.c
+++ b/sys/arch/sun3/sun3/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.29 2001/05/05 20:56:54 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.30 2001/05/05 22:34:24 art Exp $ */
/* $NetBSD: machdep.c,v 1.77 1996/10/13 03:47:51 christos Exp $ */
/*
@@ -386,7 +386,6 @@ cpu_startup()
printf("kernel does not support -c; continuing..\n");
#endif
}
- configure();
}
/*
diff --git a/sys/arch/vax/include/cpu.h b/sys/arch/vax/include/cpu.h
index 1b56bab35ce..cdb3c3bccd0 100644
--- a/sys/arch/vax/include/cpu.h
+++ b/sys/arch/vax/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.10 2000/04/26 03:08:40 bjc Exp $ */
+/* $OpenBSD: cpu.h,v 1.11 2001/05/05 22:34:26 art Exp $ */
/* $NetBSD: cpu.h,v 1.41 1999/10/21 20:01:36 ragge Exp $ */
/*
@@ -48,8 +48,6 @@
#define cpu_swapout(p)
#define cpu_number() 0
-void configure __P((void));
-
/*
* All cpu-dependent info is kept in this struct. Pointer to the
* struct for the current cpu is set up in locore.c.
diff --git a/sys/arch/vax/vax/autoconf.c b/sys/arch/vax/vax/autoconf.c
index b97195c9c37..ce7939b5300 100644
--- a/sys/arch/vax/vax/autoconf.c
+++ b/sys/arch/vax/vax/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.11 2001/02/11 06:34:37 hugh Exp $ */
+/* $OpenBSD: autoconf.c,v 1.12 2001/05/05 22:34:28 art Exp $ */
/* $NetBSD: autoconf.c,v 1.45 1999/10/23 14:56:05 ragge Exp $ */
/*
@@ -70,20 +70,20 @@ extern int cold; /* cold-start flag */
#define MAINBUS 0
void
-configure()
+cpu_configure()
{
extern int boothowto;
if (config_rootfound("mainbus", NULL) == NULL)
panic("mainbus not configured");
- setroot();
- /*
- * Configure swap area and related system
- * parameter based on device(s) used.
- */
- swapconf();
- cpu_dumpconf();
+ setroot();
+ /*
+ * Configure swap area and related system
+ * parameter based on device(s) used.
+ */
+ swapconf();
+ cpu_dumpconf();
/*
* We're ready to start up. Clear CPU cold start flag.
diff --git a/sys/arch/vax/vax/machdep.c b/sys/arch/vax/vax/machdep.c
index f6befecaed8..cde030e1f05 100644
--- a/sys/arch/vax/vax/machdep.c
+++ b/sys/arch/vax/vax/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.30 2001/05/05 20:56:56 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.31 2001/05/05 22:34:29 art Exp $ */
/* $NetBSD: machdep.c,v 1.108 2000/09/13 15:00:23 thorpej Exp $ */
/*
@@ -283,7 +283,6 @@ cpu_startup()
*/
bufinit();
- configure();
}
long dumplo = 0;
diff --git a/sys/kern/init_main.c b/sys/kern/init_main.c
index efaa53b9878..7629e6b96bc 100644
--- a/sys/kern/init_main.c
+++ b/sys/kern/init_main.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: init_main.c,v 1.62 2001/04/06 23:41:02 art Exp $ */
+/* $OpenBSD: init_main.c,v 1.63 2001/05/05 22:34:32 art Exp $ */
/* $NetBSD: init_main.c,v 1.84.4.1 1996/06/02 09:08:06 mrg Exp $ */
/*
@@ -222,6 +222,7 @@ main(framep)
disk_init(); /* must come before autoconfiguration */
tty_init(); /* initialise tty's */
cpu_startup();
+ cpu_configure();
/* Initialize sysctls (must be done before any processes run) */
sysctl_init();
diff --git a/sys/sys/systm.h b/sys/sys/systm.h
index 9b89af4d2b4..d42c14ed6ae 100644
--- a/sys/sys/systm.h
+++ b/sys/sys/systm.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: systm.h,v 1.37 2000/01/02 06:31:28 assar Exp $ */
+/* $OpenBSD: systm.h,v 1.38 2001/05/05 22:34:35 art Exp $ */
/* $NetBSD: systm.h,v 1.50 1996/06/09 04:55:09 briggs Exp $ */
/*-
@@ -261,6 +261,7 @@ void longjmp __P((label_t *));
void consinit __P((void));
void cpu_startup __P((void));
+void cpu_configure __P((void));
void cpu_set_kpc __P((struct proc *, void (*)(void *), void *));
extern void (*md_diskconf) __P((void));
diff --git a/sys/arch/hp300/hp300/autoconf.c b/sys/arch/hp300/hp300/autoconf.c
index f332cfb9e12..d11d25de971 100644
--- a/sys/arch/hp300/hp300/autoconf.c
+++ b/sys/arch/hp300/hp300/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.17 1999/05/25 08:37:49 downsj Exp $ */
+/* $OpenBSD: autoconf.c,v 1.18 2001/05/05 22:33:33 art Exp $ */
/* $NetBSD: autoconf.c,v 1.45 1999/04/10 17:31:02 kleink Exp $ */
/*
@@ -59,7 +59,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -239,7 +239,7 @@ mainbussearch(parent, match, aux)
* Determine the device configuration for the running system.
*/
void
-configure()
+cpu_configure()
{
/*
* Initialize the dev_data_lists.
@@ -59,7 +59,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
diff --git a/sys/arch/i386/i386/autoconf.c b/sys/arch/i386/i386/autoconf.c
index 16c7f3423fe..865cc5bf524 100644
--- a/sys/arch/i386/i386/autoconf.c
+++ b/sys/arch/i386/i386/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.34 2001/04/30 13:23:11 art Exp $ */
+/* $OpenBSD: autoconf.c,v 1.35 2001/05/05 22:33:44 art Exp $ */
/* $NetBSD: autoconf.c,v 1.20 1996/05/03 19:41:56 christos Exp $ */
/*-
@@ -42,7 +42,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time and initializes the vba
* device tables and the memory controller monitoring. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
@@ -80,13 +80,13 @@ dev_t bootdev = 0; /* bootdevice, initialized in locore.s */
* Determine i/o configuration for a machine.
*/
void
-configure()
+cpu_configure()
{
startrtclock();
if (config_rootfound("mainbus", NULL) == NULL)
- panic("configure: mainbus not configured");
+ panic("cpu_configure: mainbus not configured");
printf("biomask %x netmask %x ttymask %x\n",
(u_short)imask[IPL_BIO], (u_short)imask[IPL_NET],
@@ -42,7 +42,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time and initializes the vba
+ * cpu_configure() is called at boot time and initializes the vba
* device tables and the memory controller monitoring. Available
* devices are determined (from possibilities mentioned in ioconf.c),
diff --git a/sys/arch/mac68k/mac68k/autoconf.c b/sys/arch/mac68k/mac68k/autoconf.c
index 53295c83dad..7e06a8575c3 100644
--- a/sys/arch/mac68k/mac68k/autoconf.c
+++ b/sys/arch/mac68k/mac68k/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.11 1997/11/28 21:09:54 gene Exp $ */
+/* $OpenBSD: autoconf.c,v 1.12 2001/05/05 22:33:52 art Exp $ */
/* $NetBSD: autoconf.c,v 1.38 1996/12/18 05:46:09 scottr Exp $ */
/*
@@ -48,7 +48,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -91,12 +91,8 @@ static int target_to_unit __P((u_long, u_long, u_long));
void setroot __P((void));
void swapconf __P((void));
-/*
- * configure:
- * called at boot time, configure all devices on the system
- */
void
-configure()
+cpu_configure()
{
extern int cold;
@@ -48,7 +48,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
diff --git a/sys/arch/mvme68k/mvme68k/autoconf.c b/sys/arch/mvme68k/mvme68k/autoconf.c
index 69ad02b31a2..0bdaea56555 100644
--- a/sys/arch/mvme68k/mvme68k/autoconf.c
+++ b/sys/arch/mvme68k/mvme68k/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.11 2000/01/24 05:20:54 smurph Exp $ */
+/* $OpenBSD: autoconf.c,v 1.12 2001/05/05 22:33:57 art Exp $ */
/*
* Copyright (c) 1995 Theo de Raadt
@@ -74,7 +74,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -181,7 +181,8 @@ mainbus_attach(parent, self, args)
/*
* Determine mass storage and memory configuration for a machine.
*/
-configure()
+void
+cpu_configure()
{
bootdv = NULL; /* set by device drivers (if found) */
@@ -74,7 +74,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
diff --git a/sys/arch/pmax/pmax/autoconf.c b/sys/arch/pmax/pmax/autoconf.c
index d2ac9ecdd9d..fb6b5dcfac0 100644
--- a/sys/arch/pmax/pmax/autoconf.c
+++ b/sys/arch/pmax/pmax/autoconf.c
@@ -45,7 +45,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -81,11 +81,8 @@ void xconsinit __P((void)); /* XXX console-init continuation */
int spl0 __P((void));
#endif
-void configure __P((void));
void makebootdev __P((char *cp));
-
-
/*
* The following several variables are related to
* the configuration process, and are used in initializing
@@ -111,7 +108,7 @@ void configure_scsi __P((void));
* for attached scsi devices.
*/
void
-configure()
+cpu_configure()
{
int s;
@@ -45,7 +45,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
diff --git a/sys/arch/powerpc/powerpc/autoconf.c b/sys/arch/powerpc/powerpc/autoconf.c
index e0e5037e4d8..e8c1ab3432d 100644
--- a/sys/arch/powerpc/powerpc/autoconf.c
+++ b/sys/arch/powerpc/powerpc/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.10 2000/04/04 02:11:47 rahnds Exp $ */
+/* $OpenBSD: autoconf.c,v 1.11 2001/05/05 22:34:13 art Exp $ */
/*
* Copyright (c) 1996, 1997 Per Fogelstrom
* Copyright (c) 1995 Theo de Raadt
@@ -41,13 +41,13 @@
* from: Utah Hdr: autoconf.c 1.31 91/01/21
*
* from: @(#)autoconf.c 8.1 (Berkeley) 6/10/93
- * $Id: autoconf.c,v 1.10 2000/04/04 02:11:47 rahnds Exp $
+ * $Id: autoconf.c,v 1.11 2001/05/05 22:34:13 art Exp $
*/
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -64,7 +64,6 @@
struct device *parsedisk __P((char *, int, int, dev_t *));
void setroot __P((void));
-void configure __P((void));
void swapconf __P((void));
extern void dumpconf __P((void));
static int findblkmajor __P((struct device *));
@@ -89,7 +88,7 @@ struct device *bootdv = NULL;
* This is done at boot time.
*/
void
-configure()
+cpu_configure()
{
(void)splhigh(); /* To be really sure.. */
calc_delayconst();
@@ -41,13 +41,13 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
diff --git a/sys/arch/sparc/sparc/autoconf.c b/sys/arch/sparc/sparc/autoconf.c
index 013938bff48..a487edb43b1 100644
--- a/sys/arch/sparc/sparc/autoconf.c
+++ b/sys/arch/sparc/sparc/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.38 2001/04/30 16:42:25 art Exp $ */
+/* $OpenBSD: autoconf.c,v 1.39 2001/05/05 22:34:18 art Exp $ */
/* $NetBSD: autoconf.c,v 1.73 1997/07/29 09:41:53 fair Exp $ */
/*
@@ -787,7 +787,7 @@ st_crazymap(n)
* command.
*/
void
-configure()
+cpu_configure()
{
struct confargs oca;
register int node = 0;
@@ -840,14 +840,14 @@ configure()
memregcf = cf;
}
if (memregcf == NULL)
- panic("configure: no memreg found!");
+ panic("cpu_configure: no memreg found!");
rr.rr_iospace = PMAP_OBIO;
rr.rr_paddr = (void *)memregcf->cf_loc[0];
rr.rr_len = NBPG;
par_err_reg = (u_int *)bus_map(&rr, NBPG);
if (par_err_reg == NULL)
- panic("configure: ROM hasn't mapped memreg!");
+ panic("cpu_configure: ROM hasn't mapped memreg!");
}
#endif
#if defined(SUN4C)
@@ -1068,7 +1068,7 @@ int autoconf_nzs = 0; /* must be global so obio.c can see it */
/*
* Attach the mainbus.
*
* Our main job is to attach the CPU (the root node we got in configure())
* and iterate down the list of `mainbus devices' (children of that node).
* We also record the `node id' of the default frame buffer, if any.
*/
@@ -1068,7 +1068,7 @@ int autoconf_nzs = 0; /* must be global so obio.c can see it */
* Attach the mainbus.
*
- * Our main job is to attach the CPU (the root node we got in configure())
+ * Our main job is to attach the CPU (the root node we got in cpu_configure())
* and iterate down the list of `mainbus devices' (children of that node).
* We also record the `node id' of the default frame buffer, if any.
diff --git a/sys/arch/sun3/sun3/autoconf.c b/sys/arch/sun3/sun3/autoconf.c
index 7d9c7bc2c23..538fe404ca3 100644
--- a/sys/arch/sun3/sun3/autoconf.c
+++ b/sys/arch/sun3/sun3/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.9 2000/07/14 14:28:56 miod Exp $ */
+/* $OpenBSD: autoconf.c,v 1.10 2001/05/05 22:34:24 art Exp $ */
/* $NetBSD: autoconf.c,v 1.37 1996/11/20 18:57:22 gwr Exp $ */
/*-
@@ -40,7 +40,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
*/
@@ -69,14 +69,14 @@
int cold;
void
-configure()
+cpu_configure()
{
struct device *mainbus;
/* General device autoconfiguration. */
mainbus = config_rootfound("mainbus", NULL);
if (mainbus == NULL)
- panic("configure: mainbus not found");
+ panic("cpu_configure: mainbus not found");
/* Choose root and swap devices. */
swapgeneric();
@@ -40,7 +40,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time. Available
+ * cpu_configure() is called at boot time. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.